@@ -24,7 +24,7 @@ use Kernel::System::DB;
 use Kernel::System::Ticket;
 use Kernel::System::Ticket::Article;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 has 'query' => (
   traits => ['Hash'],
@@ -254,7 +254,7 @@ OTRS::ForwardQueue - Forwards the contents of an OTRS queue to a given email add
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -281,7 +281,7 @@ version 0.12
 
     my $fq = OTRS::ForwardQueue->new('query' => \%query, 'options' => \%options);
 
-    $fp->process_queue();
+    $fq->process_queue();
 
 =head1 DESCRIPTION
 
